@@ -1,5 +1,5 @@
 from .dispatchers import (DefaultDispatcher, ErrorDispatcher, SubdomainDispatcher, URLPrefixDispatcher)
 from .exception import ApiProblem
 from .handler import ErrorHandler
-from .normalize import BaseNormalize, DefaultNormalizeMixin
+from .normalize import BaseNormalize, DefaultNormalizer
 from .version import *
